from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.LifestyleModification import LifestyleModification
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Diet(LifestyleModification, CreativeWork):
    """A strategy of regulating the intake of food to achieve or maintain a specific health-related goal.

    See: https://schema.org/Diet
    Model depth: 3
    """

    type_: str = Field(default="Diet", alias="@type", const=True)
    endorsers: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="People or organizations that endorse the plan.",
    )
    dietFeatures: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Nutritional information specific to the dietary plan. May include dietary recommendations on what foods to avoid, what foods to consume, and specific alterations/deviations from the USDA or other regulatory body's approved dietary guidelines.",
    )
    risks: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Specific physiologic risks associated to the diet plan.",
    )
    physiologicalBenefits: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="Specific physiologic benefits associated to the plan.",
        )
    )
    expertConsiderations: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="Medical expert advice related to the plan.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration


class ReturnShippingFees(ReturnFeesEnumeration):
    """Specifies that the customer must pay the return shipping costs when returning a product.

    See: https://schema.org/ReturnShippingFees
    Model depth: 5
    """

    type_: str = Field(default="ReturnShippingFees", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MeasurementMethodEnum import MeasurementMethodEnum


class ExampleMeasurementMethodEnum(MeasurementMethodEnum):
    """An example [[MeasurementMethodEnum]] (to remove when real enums are added).

    See: https://schema.org/ExampleMeasurementMethodEnum
    Model depth: 5
    """

    type_: str = Field(
        default="ExampleMeasurementMethodEnum", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class PatientExperienceHealthAspect(HealthAspectEnumeration):
    """Content about the real life experience of patients or people that have lived a similar experience about the
     topic. May be forums, topics, Q-and-A and related material.

    See: https://schema.org/PatientExperienceHealthAspect
    Model depth: 5
    """

    type_: str = Field(
        default="PatientExperienceHealthAspect", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Genetic(MedicalSpecialty):
    """A specific branch of medical science that pertains to hereditary transmission and the variation of inherited
     characteristics and disorders.

    See: https://schema.org/Genetic
    Model depth: 6
    """

    type_: str = Field(default="Genetic", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWorkSeries import CreativeWorkSeries


class BookSeries(CreativeWorkSeries):
    """A series of books. Included books can be indicated with the hasPart property.

    See: https://schema.org/BookSeries
    Model depth: 4
    """

    type_: str = Field(default="BookSeries", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CivicStructure import CivicStructure


class Airport(CivicStructure):
    """An airport.

    See: https://schema.org/Airport
    Model depth: 4
    """

    type_: str = Field(default="Airport", alias="@type", const=True)
    icaoCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="ICAO identifier for an airport.",
    )
    iataCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="IATA identifier for an airline or airport.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import datetime, time


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Trip(Intangible):
    """A trip or journey. An itinerary of visits to one or more places.

    See: https://schema.org/Trip
    Model depth: 3
    """

    type_: str = Field(default="Trip", alias="@type", const=True)
    itinerary: Optional[
        Union[List[Union["Place", "ItemList", str]], "Place", "ItemList", str]
    ] = Field(
        default=None,
        description="Destination(s) ( [[Place]] ) that make up a trip. For a trip where destination order is important use [[ItemList]] to specify that order (see examples).",
    )
    departureTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The expected departure time.",
    )
    subTrip: Optional[Union[List[Union["Trip", str]], "Trip", str]] = Field(
        default=None,
        description="Identifies a [[Trip]] that is a subTrip of this Trip. For example Day 1, Day 2, etc. of a multi-day trip.",
    )
    tripOrigin: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The location of origin of the trip, prior to any destination(s).",
    )
    provider: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.",
    )
    offers: Optional[
        Union[List[Union["Demand", "Offer", str]], "Demand", "Offer", str]
    ] = Field(
        default=None,
        description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )
    arrivalTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The expected arrival time.",
    )
    partOfTrip: Optional[Union[List[Union["Trip", str]], "Trip", str]] = Field(
        default=None,
        description="Identifies that this [[Trip]] is a subTrip of another Trip. For example Day 1, Day 2, etc. of a multi-day trip.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.ItemList import ItemList
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Demand import Demand
    from pydantic2_schemaorg.Offer import Offer



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Collection import Collection
from pydantic2_schemaorg.Product import Product


class ProductCollection(Collection, Product):
    """A set of products (either [[ProductGroup]]s or specific variants) that are listed together e.g. in an [[Offer]].

    See: https://schema.org/ProductCollection
    Model depth: 3
    """

    type_: str = Field(default="ProductCollection", alias="@type", const=True)
    includesObject: Optional[
        Union[List[Union["TypeAndQuantityNode", str]], "TypeAndQuantityNode", str]
    ] = Field(
        default=None,
        description="This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.TypeAndQuantityNode import TypeAndQuantityNode



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CommunicateAction import CommunicateAction


class CheckInAction(CommunicateAction):
    """The act of an agent communicating (service provider, social media, etc) their arrival by registering/confirming
     for a previously reserved service (e.g. flight check-in) or at a place (e.g. hotel), possibly resulting in
     a result (boarding pass, etc). Related actions: * [[CheckOutAction]]: The antonym of CheckInAction. * [[ArriveAction]]:
     Unlike ArriveAction, CheckInAction implies that the agent is informing/confirming the start of a previously
     reserved service. * [[ConfirmAction]]: Unlike ConfirmAction, CheckInAction implies that the agent is
     informing/confirming the *start* of a previously reserved service rather than its validity/existence.

    See: https://schema.org/CheckInAction
    Model depth: 5
    """

    type_: str = Field(default="CheckInAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Series(Intangible):
    """A Series in schema.org is a group of related items, typically but not necessarily of the same kind. See also
     [[CreativeWorkSeries]], [[EventSeries]].

    See: https://schema.org/Series
    Model depth: 3
    """

    type_: str = Field(default="Series", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ReactAction import ReactAction


class EndorseAction(ReactAction):
    """An agent approves/certifies/likes/supports/sanctions an object.

    See: https://schema.org/EndorseAction
    Model depth: 5
    """

    type_: str = Field(default="EndorseAction", alias="@type", const=True)
    endorsee: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A sub property of participant. The person/organization being supported.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class ConsumeAction(Action):
    """The act of ingesting information/resources/food.

    See: https://schema.org/ConsumeAction
    Model depth: 3
    """

    type_: str = Field(default="ConsumeAction", alias="@type", const=True)
    actionAccessibilityRequirement: Optional[
        Union[
            List[Union["ActionAccessSpecification", str]],
            "ActionAccessSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="A set of requirements that must be fulfilled in order to perform an Action. If more than one value is specified, fulfilling one set of requirements will allow the Action to be performed.",
    )
    expectsAcceptanceOf: Optional[Union[List[Union["Offer", str]], "Offer", str]] = (
        Field(
            default=None,
            description="An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.ActionAccessSpecification import ActionAccessSpecification
    from pydantic2_schemaorg.Offer import Offer



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Vessel import Vessel


class LymphaticVessel(Vessel):
    """A type of blood vessel that specifically carries lymph fluid unidirectionally toward the heart.

    See: https://schema.org/LymphaticVessel
    Model depth: 5
    """

    type_: str = Field(default="LymphaticVessel", alias="@type", const=True)
    regionDrained: Optional[
        Union[
            List[Union["AnatomicalSystem", "AnatomicalStructure", str]],
            "AnatomicalSystem",
            "AnatomicalStructure",
            str,
        ]
    ] = Field(
        default=None,
        description="The anatomical or organ system drained by this vessel; generally refers to a specific part of an organ.",
    )
    runsTo: Optional[Union[List[Union["Vessel", str]], "Vessel", str]] = Field(
        default=None,
        description="The vasculature the lymphatic structure runs, or efferents, to.",
    )
    originatesFrom: Optional[Union[List[Union["Vessel", str]], "Vessel", str]] = Field(
        default=None,
        description="The vasculature the lymphatic structure originates, or afferents, from.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.AnatomicalSystem import AnatomicalSystem
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure
    from pydantic2_schemaorg.Vessel import Vessel



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType


class BusinessSupport(GovernmentBenefitsType):
    """BusinessSupport: this is a benefit for supporting businesses.

    See: https://schema.org/BusinessSupport
    Model depth: 5
    """

    type_: str = Field(default="BusinessSupport", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class Specialty(Enumeration):
    """Any branch of a field in which people typically develop specific expertise, usually after significant study,
     time, and effort.

    See: https://schema.org/Specialty
    Model depth: 4
    """

    type_: str = Field(default="Specialty", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Pediatric(MedicalSpecialty, MedicalBusiness):
    """A specific branch of medical science that specializes in the care of infants, children and adolescents.

    See: https://schema.org/Pediatric
    Model depth: 5
    """

    type_: str = Field(default="Pediatric", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GameServerStatus import GameServerStatus


class OfflinePermanently(GameServerStatus):
    """Game server status: OfflinePermanently. Server is offline and not available.

    See: https://schema.org/OfflinePermanently
    Model depth: 6
    """

    type_: str = Field(default="OfflinePermanently", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class ArchiveComponent(CreativeWork):
    """An intangible type to be applied to any archive content, carrying with it a set of properties required to describe
     archival items and collections.

    See: https://schema.org/ArchiveComponent
    Model depth: 3
    """

    type_: str = Field(default="ArchiveComponent", alias="@type", const=True)
    holdingArchive: Optional[
        Union[List[Union["ArchiveOrganization", str]], "ArchiveOrganization", str]
    ] = Field(
        default=None,
        description="[[ArchiveOrganization]] that holds, keeps or maintains the [[ArchiveComponent]].",
    )
    itemLocation: Optional[
        Union[
            List[Union[str, "Text", "Place", "PostalAddress"]],
            str,
            "Text",
            "Place",
            "PostalAddress",
        ]
    ] = Field(
        default=None,
        description="Current location of the item.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.ArchiveOrganization import ArchiveOrganization
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.PostalAddress import PostalAddress



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.OrganizationRole import OrganizationRole


class EmployeeRole(OrganizationRole):
    """A subclass of OrganizationRole used to describe employee relationships.

    See: https://schema.org/EmployeeRole
    Model depth: 5
    """

    type_: str = Field(default="EmployeeRole", alias="@type", const=True)
    salaryCurrency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The currency (coded using [ISO 4217](http://en.wikipedia.org/wiki/ISO_4217)) used for the main salary information in this job posting or for this employee.",
    )
    baseSalary: Optional[
        Union[
            List[
                Union[
                    StrictInt,
                    StrictFloat,
                    "Number",
                    "PriceSpecification",
                    "MonetaryAmount",
                    str,
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            "PriceSpecification",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The base salary of the job or of an employee in an EmployeeRole.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.OrderStatus import OrderStatus


class OrderProcessing(OrderStatus):
    """OrderStatus representing that an order is being processed.

    See: https://schema.org/OrderProcessing
    Model depth: 6
    """

    type_: str = Field(default="OrderProcessing", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GameAvailabilityEnumeration import GameAvailabilityEnumeration


class FullGameAvailability(GameAvailabilityEnumeration):
    """Indicates full game availability.

    See: https://schema.org/FullGameAvailability
    Model depth: 5
    """

    type_: str = Field(default="FullGameAvailability", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Service(Intangible):
    """A service provided by an organization, e.g. delivery service, print services, etc.

    See: https://schema.org/Service
    Model depth: 3
    """

    type_: str = Field(default="Service", alias="@type", const=True)
    audience: Optional[Union[List[Union["Audience", str]], "Audience", str]] = Field(
        default=None,
        description="An intended audience, i.e. a group for whom something was created.",
    )
    category: Optional[
        Union[
            List[
                Union[
                    AnyUrl,
                    "URL",
                    str,
                    "Text",
                    "PhysicalActivityCategory",
                    "CategoryCode",
                    "Thing",
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PhysicalActivityCategory",
            "CategoryCode",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.",
    )
    serviceType: Optional[
        Union[
            List[Union[str, "Text", "GovernmentBenefitsType"]],
            str,
            "Text",
            "GovernmentBenefitsType",
        ]
    ] = Field(
        default=None,
        description="The type of service being offered, e.g. veterans' benefits, emergency relief, etc.",
    )
    isSimilarTo: Optional[
        Union[List[Union["Service", "Product", str]], "Service", "Product", str]
    ] = Field(
        default=None,
        description="A pointer to another, functionally similar product (or multiple products).",
    )
    logo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "ImageObject", str]],
            AnyUrl,
            "URL",
            "ImageObject",
            str,
        ]
    ] = Field(
        default=None,
        description="An associated logo.",
    )
    serviceOutput: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The tangible thing generated by the service, e.g. a passport, permit, etc.",
    )
    serviceArea: Optional[
        Union[
            List[Union["Place", "GeoShape", "AdministrativeArea", str]],
            "Place",
            "GeoShape",
            "AdministrativeArea",
            str,
        ]
    ] = Field(
        default=None,
        description="The geographic area where the service is provided.",
    )
    hasCertification: Optional[
        Union[List[Union["Certification", str]], "Certification", str]
    ] = Field(
        default=None,
        description="Certification information about a product, organization, service, place, or person.",
    )
    hoursAvailable: Optional[
        Union[
            List[Union["OpeningHoursSpecification", str]],
            "OpeningHoursSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The hours during which this service or contact is available.",
    )
    aggregateRating: Optional[
        Union[List[Union["AggregateRating", str]], "AggregateRating", str]
    ] = Field(
        default=None,
        description="The overall rating, based on a collection of reviews or ratings, of the item.",
    )
    brand: Optional[
        Union[List[Union["Brand", "Organization", str]], "Brand", "Organization", str]
    ] = Field(
        default=None,
        description="The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.",
    )
    broker: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.",
    )
    serviceAudience: Optional[Union[List[Union["Audience", str]], "Audience", str]] = (
        Field(
            default=None,
            description="The audience eligible for this service.",
        )
    )
    availableChannel: Optional[
        Union[List[Union["ServiceChannel", str]], "ServiceChannel", str]
    ] = Field(
        default=None,
        description="A means of accessing the service (e.g. a phone bank, a web site, a location, etc.).",
    )
    termsOfService: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="Human-readable terms of service documentation.",
    )
    slogan: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A slogan or motto associated with the item.",
    )
    providerMobility: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Indicates the mobility of a provided service (e.g. 'static', 'dynamic').",
    )
    hasOfferCatalog: Optional[
        Union[List[Union["OfferCatalog", str]], "OfferCatalog", str]
    ] = Field(
        default=None,
        description="Indicates an OfferCatalog listing for this Organization, Person, or Service.",
    )
    award: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An award won by or for this item.",
    )
    review: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="A review of the item.",
    )
    areaServed: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape", "AdministrativeArea"]],
            str,
            "Text",
            "Place",
            "GeoShape",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="The geographic area where a service or offered item is provided.",
    )
    produces: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The tangible thing generated by the service, e.g. a passport, permit, etc.",
    )
    provider: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.",
    )
    offers: Optional[
        Union[List[Union["Demand", "Offer", str]], "Demand", "Offer", str]
    ] = Field(
        default=None,
        description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )
    isRelatedTo: Optional[
        Union[List[Union["Service", "Product", str]], "Service", "Product", str]
    ] = Field(
        default=None,
        description="A pointer to another, somehow related product (or multiple products).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.ImageObject import ImageObject
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.GeoShape import GeoShape
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Certification import Certification
    from pydantic2_schemaorg.OpeningHoursSpecification import OpeningHoursSpecification
    from pydantic2_schemaorg.AggregateRating import AggregateRating
    from pydantic2_schemaorg.Brand import Brand
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.ServiceChannel import ServiceChannel
    from pydantic2_schemaorg.OfferCatalog import OfferCatalog
    from pydantic2_schemaorg.Review import Review
    from pydantic2_schemaorg.Demand import Demand
    from pydantic2_schemaorg.Offer import Offer



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class Joint(AnatomicalStructure):
    """The anatomical location at which two or more bones make contact.

    See: https://schema.org/Joint
    Model depth: 4
    """

    type_: str = Field(default="Joint", alias="@type", const=True)
    structuralClass: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The name given to how bone physically connects to each other.",
    )
    biomechnicalClass: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The biomechanical properties of the bone.",
    )
    functionalClass: Optional[
        Union[List[Union[str, "Text", "MedicalEntity"]], str, "Text", "MedicalEntity"]
    ] = Field(
        default=None,
        description="The degree of mobility the joint allows.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class MeasurementMethodEnum(Enumeration):
    """Enumeration(s) for use with [[measurementMethod]].

    See: https://schema.org/MeasurementMethodEnum
    Model depth: 4
    """

    type_: str = Field(default="MeasurementMethodEnum", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalProcedure import MedicalProcedure


class TherapeuticProcedure(MedicalProcedure):
    """A medical procedure intended primarily for therapeutic purposes, aimed at improving a health condition.

    See: https://schema.org/TherapeuticProcedure
    Model depth: 4
    """

    type_: str = Field(default="TherapeuticProcedure", alias="@type", const=True)
    doseSchedule: Optional[
        Union[List[Union["DoseSchedule", str]], "DoseSchedule", str]
    ] = Field(
        default=None,
        description="A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.",
    )
    adverseOutcome: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or otherwise life-threatening or requiring immediate medical attention), tag it as a seriousAdverseOutcome instead.",
    )
    drug: Optional[Union[List[Union["Drug", str]], "Drug", str]] = Field(
        default=None,
        description="Specifying a drug or medicine used in a medication procedure.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DoseSchedule import DoseSchedule
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.Drug import Drug



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Thing import Thing


class Taxon(Thing):
    """A set of organisms asserted to represent a natural cohesive biological unit.

    See: https://schema.org/Taxon
    Model depth: 2
    """

    type_: str = Field(default="Taxon", alias="@type", const=True)
    taxonRank: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "PropertyValue"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PropertyValue",
        ]
    ] = Field(
        default=None,
        description="The taxonomic rank of this taxon given preferably as a URI from a controlled vocabulary – typically the ranks from TDWG TaxonRank ontology or equivalent Wikidata URIs.",
    )
    hasDefinedTerm: Optional[
        Union[List[Union["DefinedTerm", str]], "DefinedTerm", str]
    ] = Field(
        default=None,
        description="A Defined Term contained in this term set.",
    )
    parentTaxon: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Taxon"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Taxon",
        ]
    ] = Field(
        default=None,
        description="Closest parent taxon of the taxon in question.",
    )
    childTaxon: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Taxon"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Taxon",
        ]
    ] = Field(
        default=None,
        description="Closest child taxa of the taxon in question.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool


from pydantic.v1 import Field
from pydantic2_schemaorg.Substance import Substance
from pydantic2_schemaorg.Product import Product


class Drug(Substance, Product):
    """A chemical or biologic substance, used as a medical therapy, that has a physiological effect on an organism.
     Here the term drug is used interchangeably with the term medicine although clinical knowledge makes a clear
     difference between them.

    See: https://schema.org/Drug
    Model depth: 3
    """

    type_: str = Field(default="Drug", alias="@type", const=True)
    proprietaryName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Proprietary name given to the diet plan, typically by its originator or creator.",
    )
    doseSchedule: Optional[
        Union[List[Union["DoseSchedule", str]], "DoseSchedule", str]
    ] = Field(
        default=None,
        description="A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.",
    )
    drugUnit: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The unit in which the drug is measured, e.g. '5 mg tablet'.",
    )
    warning: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="Any FDA or other warnings about the drug (text or URL).",
    )
    nonProprietaryName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The generic name of this drug or supplement.",
    )
    maximumIntake: Optional[
        Union[List[Union["MaximumDoseSchedule", str]], "MaximumDoseSchedule", str]
    ] = Field(
        default=None,
        description="Recommended intake of this supplement for a given population as defined by a specific recommending authority.",
    )
    legalStatus: Optional[
        Union[
            List[Union[str, "Text", "DrugLegalStatus", "MedicalEnumeration"]],
            str,
            "Text",
            "DrugLegalStatus",
            "MedicalEnumeration",
        ]
    ] = Field(
        default=None,
        description="The drug or supplement's legal status, including any controlled substance schedules that apply.",
    )
    clincalPharmacology: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).",
    )
    activeIngredient: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An active ingredient, typically chemical compounds and/or biologic substances.",
    )
    relatedDrug: Optional[Union[List[Union["Drug", str]], "Drug", str]] = Field(
        default=None,
        description="Any other drug related to this one, for example commonly-prescribed alternatives.",
    )
    pregnancyWarning: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Any precaution, guidance, contraindication, etc. related to this drug's use during pregnancy.",
    )
    drugClass: Optional[Union[List[Union["DrugClass", str]], "DrugClass", str]] = Field(
        default=None,
        description="The class of drug this belongs to (e.g., statins).",
    )
    rxcui: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The RxCUI drug identifier from RXNORM.",
    )
    clinicalPharmacology: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).",
        )
    )
    isAvailableGenerically: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="True if the drug is available in a generic form (regardless of name).",
    )
    availableStrength: Optional[
        Union[List[Union["DrugStrength", str]], "DrugStrength", str]
    ] = Field(
        default=None,
        description="An available dosage strength for the drug.",
    )
    prescribingInfo: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="Link to prescribing information for the drug.",
    )
    alcoholWarning: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Any precaution, guidance, contraindication, etc. related to consumption of alcohol while taking this drug.",
    )
    mechanismOfAction: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.",
    )
    breastfeedingWarning: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="Any precaution, guidance, contraindication, etc. related to this drug's use by breastfeeding mothers.",
        )
    )
    includedInHealthInsurancePlan: Optional[
        Union[List[Union["HealthInsurancePlan", str]], "HealthInsurancePlan", str]
    ] = Field(
        default=None,
        description="The insurance plans that cover this drug.",
    )
    labelDetails: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="Link to the drug's label details.",
    )
    isProprietary: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="True if this item's name is a proprietary/brand name (vs. generic name).",
    )
    pregnancyCategory: Optional[
        Union[List[Union["DrugPregnancyCategory", str]], "DrugPregnancyCategory", str]
    ] = Field(
        default=None,
        description="Pregnancy category of this drug.",
    )
    dosageForm: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A dosage form in which this drug/supplement is available, e.g. 'tablet', 'suspension', 'injection'.",
    )
    prescriptionStatus: Optional[
        Union[
            List[Union[str, "Text", "DrugPrescriptionStatus"]],
            str,
            "Text",
            "DrugPrescriptionStatus",
        ]
    ] = Field(
        default=None,
        description="Indicates the status of drug prescription, e.g. local catalogs classifications or whether the drug is available by prescription or over-the-counter, etc.",
    )
    administrationRoute: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A route by which this drug may be administered, e.g. 'oral'.",
    )
    overdosage: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response.",
    )
    interactingDrug: Optional[Union[List[Union["Drug", str]], "Drug", str]] = Field(
        default=None,
        description="Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient. Note: disease interactions are typically captured as contraindications.",
    )
    foodWarning: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Any precaution, guidance, contraindication, etc. related to consumption of specific foods while taking this drug.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DoseSchedule import DoseSchedule
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.MaximumDoseSchedule import MaximumDoseSchedule
    from pydantic2_schemaorg.DrugLegalStatus import DrugLegalStatus
    from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration
    from pydantic2_schemaorg.DrugClass import DrugClass
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.DrugStrength import DrugStrength
    from pydantic2_schemaorg.HealthInsurancePlan import HealthInsurancePlan
    from pydantic2_schemaorg.DrugPregnancyCategory import DrugPregnancyCategory
    from pydantic2_schemaorg.DrugPrescriptionStatus import DrugPrescriptionStatus



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Accommodation import Accommodation


class House(Accommodation):
    """A house is a building or structure that has the ability to be occupied for habitation by humans or other creatures
     (source: Wikipedia, the free encyclopedia, see <a href=\"http://en.wikipedia.org/wiki/House\">http://en.wikipedia.org/wiki/House</a>).

    See: https://schema.org/House
    Model depth: 4
    """

    type_: str = Field(default="House", alias="@type", const=True)
    numberOfRooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Landform import Landform


class BodyOfWater(Landform):
    """A body of water, such as a sea, ocean, or lake.

    See: https://schema.org/BodyOfWater
    Model depth: 4
    """

    type_: str = Field(default="BodyOfWater", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class SuperficialAnatomy(MedicalEntity):
    """Anatomical features that can be observed by sight (without dissection), including the form and proportions
     of the human body as well as surface landmarks that correspond to deeper subcutaneous structures. Superficial
     anatomy plays an important role in sports medicine, phlebotomy, and other medical specialties as underlying
     anatomical structures can be identified through surface palpation. For example, during back surgery, superficial
     anatomy can be used to palpate and count vertebrae to find the site of incision. Or in phlebotomy, superficial
     anatomy can be used to locate an underlying vein; for example, the median cubital vein can be located by palpating
     the borders of the cubital fossa (such as the epicondyles of the humerus) and then looking for the superficial
     signs of the vein, such as size, prominence, ability to refill after depression, and feel of surrounding tissue
     support. As another example, in a subluxation (dislocation) of the glenohumeral joint, the bony structure
     becomes pronounced with the deltoid muscle failing to cover the glenohumeral joint allowing the edges of
     the scapula to be superficially visible. Here, the superficial anatomy is the visible edges of the scapula,
     implying the underlying dislocation of the joint (the related anatomical structure).

    See: https://schema.org/SuperficialAnatomy
    Model depth: 3
    """

    type_: str = Field(default="SuperficialAnatomy", alias="@type", const=True)
    relatedAnatomy: Optional[
        Union[
            List[Union["AnatomicalSystem", "AnatomicalStructure", str]],
            "AnatomicalSystem",
            "AnatomicalStructure",
            str,
        ]
    ] = Field(
        default=None,
        description="Anatomical systems or structures that relate to the superficial anatomy.",
    )
    significance: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment.",
    )
    associatedPathophysiology: Optional[
        Union[List[Union[str, "Text"]], str, "Text"]
    ] = Field(
        default=None,
        description="If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.",
    )
    relatedCondition: Optional[
        Union[List[Union["MedicalCondition", str]], "MedicalCondition", str]
    ] = Field(
        default=None,
        description="A medical condition associated with this anatomy.",
    )
    relatedTherapy: Optional[
        Union[List[Union["MedicalTherapy", str]], "MedicalTherapy", str]
    ] = Field(
        default=None,
        description="A medical therapy related to this anatomy.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.AnatomicalSystem import AnatomicalSystem
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalCondition import MedicalCondition
    from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory


class Flexibility(PhysicalActivityCategory):
    """Physical activity that is engaged in to improve joint and muscle flexibility.

    See: https://schema.org/Flexibility
    Model depth: 5
    """

    type_: str = Field(default="Flexibility", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Trip import Trip


class BoatTrip(Trip):
    """A trip on a commercial ferry line.

    See: https://schema.org/BoatTrip
    Model depth: 4
    """

    type_: str = Field(default="BoatTrip", alias="@type", const=True)
    departureBoatTerminal: Optional[
        Union[List[Union["BoatTerminal", str]], "BoatTerminal", str]
    ] = Field(
        default=None,
        description="The terminal or port from which the boat departs.",
    )
    arrivalBoatTerminal: Optional[
        Union[List[Union["BoatTerminal", str]], "BoatTerminal", str]
    ] = Field(
        default=None,
        description="The terminal or port from which the boat arrives.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.BoatTerminal import BoatTerminal



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EventAttendanceModeEnumeration import (
    EventAttendanceModeEnumeration,
)


class MixedEventAttendanceMode(EventAttendanceModeEnumeration):
    """MixedEventAttendanceMode - an event that is conducted as a combination of both offline and online modes.

    See: https://schema.org/MixedEventAttendanceMode
    Model depth: 5
    """

    type_: str = Field(default="MixedEventAttendanceMode", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HowToItem import HowToItem


class HowToTool(HowToItem):
    """A tool used (but not consumed) when performing instructions for how to achieve a result.

    See: https://schema.org/HowToTool
    Model depth: 5
    """

    type_: str = Field(default="HowToTool", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WearableMeasurementTypeEnumeration import (
    WearableMeasurementTypeEnumeration,
)


class WearableMeasurementHeight(WearableMeasurementTypeEnumeration):
    """Measurement of the height, for example the heel height of a shoe.

    See: https://schema.org/WearableMeasurementHeight
    Model depth: 6
    """

    type_: str = Field(default="WearableMeasurementHeight", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class HowOrWhereHealthAspect(HealthAspectEnumeration):
    """Information about how or where to find a topic. Also may contain location data that can be used for where to look
     for help if the topic is observed.

    See: https://schema.org/HowOrWhereHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="HowOrWhereHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration


class ListPrice(PriceTypeEnumeration):
    """Represents the list price of an offered product.

    See: https://schema.org/ListPrice
    Model depth: 5
    """

    type_: str = Field(default="ListPrice", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class MusicAlbumProductionType(Enumeration):
    """Classification of the album by its type of content: soundtrack, live album, studio album, etc.

    See: https://schema.org/MusicAlbumProductionType
    Model depth: 4
    """

    type_: str = Field(default="MusicAlbumProductionType", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness
from pydantic2_schemaorg.MedicalOrganization import MedicalOrganization


class MedicalClinic(MedicalBusiness, MedicalOrganization):
    """A facility, often associated with a hospital or medical school, that is devoted to the specific diagnosis
     and/or healthcare. Previously limited to outpatients but with evolution it may be open to inpatients as well.

    See: https://schema.org/MedicalClinic
    Model depth: 4
    """

    type_: str = Field(default="MedicalClinic", alias="@type", const=True)
    availableService: Optional[
        Union[
            List[Union["MedicalTherapy", "MedicalProcedure", "MedicalTest", str]],
            "MedicalTherapy",
            "MedicalProcedure",
            "MedicalTest",
            str,
        ]
    ] = Field(
        default=None,
        description="A medical service available from this provider.",
    )
    medicalSpecialty: Optional[
        Union[List[Union["MedicalSpecialty", str]], "MedicalSpecialty", str]
    ] = Field(
        default=None,
        description="A medical specialty of the provider.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy
    from pydantic2_schemaorg.MedicalProcedure import MedicalProcedure
    from pydantic2_schemaorg.MedicalTest import MedicalTest
    from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Role(Intangible):
    """Represents additional information about a relationship or property. For example a Role can be used to say
     that a 'member' role linking some SportsTeam to a player occurred during a particular time period. Or that
     a Person's 'actor' role in a Movie was for some particular characterName. Such properties can be attached
     to a Role entity, which is then associated with the main entities using ordinary properties like 'member'
     or 'actor'. See also [blog post](http://blog.schema.org/2014/06/introducing-role.html).

    See: https://schema.org/Role
    Model depth: 3
    """

    type_: str = Field(default="Role", alias="@type", const=True)
    endDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    namedPosition: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="A position played, performed or filled by a person or organization, as part of an organization. For example, an athlete in a SportsTeam might play in the position named 'Quarterback'.",
    )
    roleName: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="A role played, performed or filled by a person or organization. For example, the team of creators for a comic book might fill the roles named 'inker', 'penciller', and 'letterer'; or an athlete in a SportsTeam might play in the position named 'Quarterback'.",
    )
    startDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AutomotiveBusiness import AutomotiveBusiness


class AutoWash(AutomotiveBusiness):
    """A car wash business.

    See: https://schema.org/AutoWash
    Model depth: 5
    """

    type_: str = Field(default="AutoWash", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementWeight(BodyMeasurementTypeEnumeration):
    """Body weight. Used, for example, to measure pantyhose.

    See: https://schema.org/BodyMeasurementWeight
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementWeight", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PerformingGroup import PerformingGroup


class MusicGroup(PerformingGroup):
    """A musical group, such as a band, an orchestra, or a choir. Can also be a solo musician.

    See: https://schema.org/MusicGroup
    Model depth: 4
    """

    type_: str = Field(default="MusicGroup", alias="@type", const=True)
    genre: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="Genre of the creative work, broadcast channel or group.",
    )
    musicGroupMember: Optional[Union[List[Union["Person", str]], "Person", str]] = (
        Field(
            default=None,
            description="A member of a music group&#x2014;for example, John, Paul, George, or Ringo.",
        )
    )
    albums: Optional[Union[List[Union["MusicAlbum", str]], "MusicAlbum", str]] = Field(
        default=None,
        description="A collection of music albums.",
    )
    tracks: Optional[
        Union[List[Union["MusicRecording", str]], "MusicRecording", str]
    ] = Field(
        default=None,
        description="A music recording (track)&#x2014;usually a single song.",
    )
    album: Optional[Union[List[Union["MusicAlbum", str]], "MusicAlbum", str]] = Field(
        default=None,
        description="A music album.",
    )
    track: Optional[
        Union[
            List[Union["ItemList", "MusicRecording", str]],
            "ItemList",
            "MusicRecording",
            str,
        ]
    ] = Field(
        default=None,
        description="A music recording (track)&#x2014;usually a single song. If an ItemList is given, the list should contain items of type MusicRecording.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.MusicAlbum import MusicAlbum
    from pydantic2_schemaorg.MusicRecording import MusicRecording
    from pydantic2_schemaorg.ItemList import ItemList



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.QualitativeValue import QualitativeValue


class SteeringPositionValue(QualitativeValue):
    """A value indicating a steering position.

    See: https://schema.org/SteeringPositionValue
    Model depth: 5
    """

    type_: str = Field(default="SteeringPositionValue", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class MedicalEnumeration(Enumeration):
    """Enumerations related to health and the practice of medicine: A concept that is used to attribute a quality
     to another concept, as a qualifier, a collection of items or a listing of all of the elements of a set in medicine
     practice.

    See: https://schema.org/MedicalEnumeration
    Model depth: 4
    """

    type_: str = Field(default="MedicalEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LearningResource import LearningResource


class Quiz(LearningResource):
    """Quiz: A test of knowledge, skills and abilities.

    See: https://schema.org/Quiz
    Model depth: 4
    """

    type_: str = Field(default="Quiz", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MoveAction import MoveAction


class ArriveAction(MoveAction):
    """The act of arriving at a place. An agent arrives at a destination from a fromLocation, optionally with participants.

    See: https://schema.org/ArriveAction
    Model depth: 4
    """

    type_: str = Field(default="ArriveAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration


class DrugPregnancyCategory(MedicalEnumeration):
    """Categories that represent an assessment of the risk of fetal injury due to a drug or pharmaceutical used as
     directed by the mother during pregnancy.

    See: https://schema.org/DrugPregnancyCategory
    Model depth: 5
    """

    type_: str = Field(default="DrugPregnancyCategory", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class PlayAction(Action):
    """The act of playing/exercising/training/performing for enjoyment, leisure, recreation, competition
     or exercise. Related actions: * [[ListenAction]]: Unlike ListenAction (which is under ConsumeAction),
     PlayAction refers to performing for an audience or at an event, rather than consuming music. * [[WatchAction]]:
     Unlike WatchAction (which is under ConsumeAction), PlayAction refers to showing/displaying for an audience
     or at an event, rather than consuming visual content.

    See: https://schema.org/PlayAction
    Model depth: 3
    """

    type_: str = Field(default="PlayAction", alias="@type", const=True)
    audience: Optional[Union[List[Union["Audience", str]], "Audience", str]] = Field(
        default=None,
        description="An intended audience, i.e. a group for whom something was created.",
    )
    event: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="Upcoming or past event associated with this place, organization, or action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Event import Event



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea


class SchoolDistrict(AdministrativeArea):
    """A School District is an administrative area for the administration of schools.

    See: https://schema.org/SchoolDistrict
    Model depth: 4
    """

    type_: str = Field(default="SchoolDistrict", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalProcedure import MedicalProcedure


class DiagnosticProcedure(MedicalProcedure):
    """A medical procedure intended primarily for diagnostic, as opposed to therapeutic, purposes.

    See: https://schema.org/DiagnosticProcedure
    Model depth: 4
    """

    type_: str = Field(default="DiagnosticProcedure", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialProduct import FinancialProduct


class LoanOrCredit(FinancialProduct):
    """A financial product for the loaning of an amount of money, or line of credit, under agreed terms and charges.

    See: https://schema.org/LoanOrCredit
    Model depth: 5
    """

    type_: str = Field(default="LoanOrCredit", alias="@type", const=True)
    currency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency in which the monetary amount is expressed. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    loanRepaymentForm: Optional[
        Union[List[Union["RepaymentSpecification", str]], "RepaymentSpecification", str]
    ] = Field(
        default=None,
        description="A form of paying back money previously borrowed from a lender. Repayment usually takes the form of periodic payments that normally include part principal plus interest in each payment.",
    )
    gracePeriod: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The period of time after any due date that the borrower has to fulfil its obligations before a default (failure to pay) is deemed to have occurred.",
    )
    amount: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The amount of money.",
    )
    recourseLoan: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="The only way you get the money back in the event of default is the security. Recourse is where you still have the opportunity to go back to the borrower for the rest of the money.",
    )
    loanTerm: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The duration of the loan or credit agreement.",
    )
    loanType: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The type of a loan or credit.",
    )
    renegotiableLoan: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Whether the terms for payment of interest can be renegotiated during the life of the loan.",
    )
    requiredCollateral: Optional[
        Union[List[Union[str, "Text", "Thing"]], str, "Text", "Thing"]
    ] = Field(
        default=None,
        description="Assets required to secure loan or credit repayments. It may take form of third party pledge, goods, financial instruments (cash, securities, etc.)",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.RepaymentSpecification import RepaymentSpecification
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Thing import Thing



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class HealthPlanFormulary(Intangible):
    """For a given health insurance plan, the specification for costs and coverage of prescription drugs.

    See: https://schema.org/HealthPlanFormulary
    Model depth: 3
    """

    type_: str = Field(default="HealthPlanFormulary", alias="@type", const=True)
    healthPlanCostSharing: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="The costs to the patient for services under this network or formulary.",
    )
    offersPrescriptionByMail: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Whether prescriptions can be delivered by mail.",
    )
    healthPlanDrugTier: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The tier(s) of drugs offered by this formulary or insurance plan.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialService import FinancialService


class InsuranceAgency(FinancialService):
    """An Insurance agency.

    See: https://schema.org/InsuranceAgency
    Model depth: 5
    """

    type_: str = Field(default="InsuranceAgency", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Invoice(Intangible):
    """A statement of the money due for goods or services; a bill.

    See: https://schema.org/Invoice
    Model depth: 3
    """

    type_: str = Field(default="Invoice", alias="@type", const=True)
    paymentStatus: Optional[
        Union[
            List[Union[str, "Text", "PaymentStatusType"]],
            str,
            "Text",
            "PaymentStatusType",
        ]
    ] = Field(
        default=None,
        description="The status of payment; whether the invoice has been paid or not.",
    )
    totalPaymentDue: Optional[
        Union[
            List[Union["MonetaryAmount", "PriceSpecification", str]],
            "MonetaryAmount",
            "PriceSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The total amount due.",
    )
    category: Optional[
        Union[
            List[
                Union[
                    AnyUrl,
                    "URL",
                    str,
                    "Text",
                    "PhysicalActivityCategory",
                    "CategoryCode",
                    "Thing",
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PhysicalActivityCategory",
            "CategoryCode",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.",
    )
    accountId: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The identifier for the account the payment will be applied to.",
    )
    paymentMethod: Optional[
        Union[List[Union["PaymentMethod", str]], "PaymentMethod", str]
    ] = Field(
        default=None,
        description="The name of the credit card or other method of payment for the order.",
    )
    paymentDue: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The date that payment is due.",
    )
    paymentDueDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date that payment is due.",
    )
    broker: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.",
    )
    billingPeriod: Optional[Union[List[Union["Duration", str]], "Duration", str]] = (
        Field(
            default=None,
            description="The time interval used to compute the invoice.",
        )
    )
    scheduledPaymentDate: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description="The date the invoice is scheduled to be paid.",
    )
    confirmationNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A number that confirms the given order or payment has been received.",
    )
    minimumPaymentDue: Optional[
        Union[
            List[Union["MonetaryAmount", "PriceSpecification", str]],
            "MonetaryAmount",
            "PriceSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The minimum payment required at this time.",
    )
    provider: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.",
    )
    referencesOrder: Optional[Union[List[Union["Order", str]], "Order", str]] = Field(
        default=None,
        description="The Order(s) related to this Invoice. One or more Orders may be combined into a single Invoice.",
    )
    customer: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="Party placing the order or paying the invoice.",
    )
    paymentMethodId: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An identifier for the method of payment used (e.g. the last 4 digits of the credit card).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PaymentStatusType import PaymentStatusType
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.PaymentMethod import PaymentMethod
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.Order import Order



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class OfferItemCondition(Enumeration):
    """A list of possible conditions for the item.

    See: https://schema.org/OfferItemCondition
    Model depth: 4
    """

    type_: str = Field(default="OfferItemCondition", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalStudy import MedicalStudy


class MedicalObservationalStudy(MedicalStudy):
    """An observational study is a type of medical study that attempts to infer the possible effect of a treatment
     through observation of a cohort of subjects over a period of time. In an observational study, the assignment
     of subjects into treatment groups versus control groups is outside the control of the investigator. This
     is in contrast with controlled studies, such as the randomized controlled trials represented by MedicalTrial,
     where each subject is randomly assigned to a treatment group or a control group before the start of the treatment.

    See: https://schema.org/MedicalObservationalStudy
    Model depth: 4
    """

    type_: str = Field(default="MedicalObservationalStudy", alias="@type", const=True)
    studyDesign: Optional[
        Union[
            List[Union["MedicalObservationalStudyDesign", str]],
            "MedicalObservationalStudyDesign",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifics about the observational study design (enumerated).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalObservationalStudyDesign import (
        MedicalObservationalStudyDesign,
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSignOrSymptom import MedicalSignOrSymptom


class MedicalSign(MedicalSignOrSymptom):
    """Any physical manifestation of a person's medical condition discoverable by objective diagnostic tests
     or physical examination.

    See: https://schema.org/MedicalSign
    Model depth: 5
    """

    type_: str = Field(default="MedicalSign", alias="@type", const=True)
    identifyingExam: Optional[
        Union[List[Union["PhysicalExam", str]], "PhysicalExam", str]
    ] = Field(
        default=None,
        description="A physical examination that can identify this sign.",
    )
    identifyingTest: Optional[
        Union[List[Union["MedicalTest", str]], "MedicalTest", str]
    ] = Field(
        default=None,
        description="A diagnostic test that can identify this sign.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.PhysicalExam import PhysicalExam
    from pydantic2_schemaorg.MedicalTest import MedicalTest



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class PlasticSurgery(MedicalSpecialty, MedicalBusiness):
    """A specific branch of medical science that pertains to therapeutic or cosmetic repair or re-formation of missing,
     injured or malformed tissues or body parts by manual and instrumental means.

    See: https://schema.org/PlasticSurgery
    Model depth: 5
    """

    type_: str = Field(default="PlasticSurgery", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class FollowAction(InteractAction):
    """The act of forming a personal connection with someone/something (object) unidirectionally/asymmetrically
     to get updates polled from. Related actions: * [[BefriendAction]]: Unlike BefriendAction, FollowAction
     implies that the connection is *not* necessarily reciprocal. * [[SubscribeAction]]: Unlike SubscribeAction,
     FollowAction implies that the follower acts as an active agent constantly/actively polling for updates.
     * [[RegisterAction]]: Unlike RegisterAction, FollowAction implies that the agent is interested in continuing
     receiving updates from the object. * [[JoinAction]]: Unlike JoinAction, FollowAction implies that the
     agent is interested in getting updates from the object. * [[TrackAction]]: Unlike TrackAction, FollowAction
     refers to the polling of updates of all aspects of animate objects rather than the location of inanimate objects
     (e.g. you track a package, but you don't follow it).

    See: https://schema.org/FollowAction
    Model depth: 4
    """

    type_: str = Field(default="FollowAction", alias="@type", const=True)
    followee: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A sub property of object. The person or organization being followed.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MapCategoryType import MapCategoryType


class ParkingMap(MapCategoryType):
    """A parking map.

    See: https://schema.org/ParkingMap
    Model depth: 5
    """

    type_: str = Field(default="ParkingMap", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class Ligament(AnatomicalStructure):
    """A short band of tough, flexible, fibrous connective tissue that functions to connect multiple bones, cartilages,
     and structurally support joints.

    See: https://schema.org/Ligament
    Model depth: 4
    """

    type_: str = Field(default="Ligament", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Review import Review


class EmployerReview(Review):
    """An [[EmployerReview]] is a review of an [[Organization]] regarding its role as an employer, written by a current
     or former employee of that organization.

    See: https://schema.org/EmployerReview
    Model depth: 4
    """

    type_: str = Field(default="EmployerReview", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicPlaylist import MusicPlaylist


class MusicAlbum(MusicPlaylist):
    """A collection of music tracks.

    See: https://schema.org/MusicAlbum
    Model depth: 4
    """

    type_: str = Field(default="MusicAlbum", alias="@type", const=True)
    albumRelease: Optional[
        Union[List[Union["MusicRelease", str]], "MusicRelease", str]
    ] = Field(
        default=None,
        description="A release of this album.",
    )
    byArtist: Optional[
        Union[List[Union["Person", "MusicGroup", str]], "Person", "MusicGroup", str]
    ] = Field(
        default=None,
        description="The artist that performed this album or recording.",
    )
    albumProductionType: Optional[
        Union[
            List[Union["MusicAlbumProductionType", str]],
            "MusicAlbumProductionType",
            str,
        ]
    ] = Field(
        default=None,
        description="Classification of the album by its type of content: soundtrack, live album, studio album, etc.",
    )
    albumReleaseType: Optional[
        Union[List[Union["MusicAlbumReleaseType", str]], "MusicAlbumReleaseType", str]
    ] = Field(
        default=None,
        description="The kind of release which this album is: single, EP or album.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MusicRelease import MusicRelease
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.MusicGroup import MusicGroup
    from pydantic2_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
    from pydantic2_schemaorg.MusicAlbumReleaseType import MusicAlbumReleaseType



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.WebPage import WebPage


class RealEstateListing(WebPage):
    """A [[RealEstateListing]] is a listing that describes one or more real-estate [[Offer]]s (whose [[businessFunction]]
     is typically to lease out, or to sell). The [[RealEstateListing]] type itself represents the overall listing,
     as manifested in some [[WebPage]].

    See: https://schema.org/RealEstateListing
    Model depth: 4
    """

    type_: str = Field(default="RealEstateListing", alias="@type", const=True)
    datePosted: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Publication date of an online listing.",
    )
    leaseLength: Optional[
        Union[
            List[Union["Duration", "QuantitativeValue", str]],
            "Duration",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Length of the lease for some [[Accommodation]], either particular to some [[Offer]] or in some cases intrinsic to the property.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Product import Product


class SomeProducts(Product):
    """A placeholder for multiple similar products of the same kind.

    See: https://schema.org/SomeProducts
    Model depth: 3
    """

    type_: str = Field(default="SomeProducts", alias="@type", const=True)
    inventoryLevel: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The current approximate inventory level for the item or items.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class PharmacySpecialty(MedicalSpecialty):
    """The practice or art and science of preparing and dispensing drugs and medicines.

    See: https://schema.org/PharmacySpecialty
    Model depth: 6
    """

    type_: str = Field(default="PharmacySpecialty", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictBool, StrictInt, StrictFloat
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class PriceSpecification(StructuredValue):
    """A structured value representing a price or price range. Typically, only the subclasses of this type are used
     for markup. It is recommended to use [[MonetaryAmount]] to describe independent amounts of money such as
     a salary, credit card limits, etc.

    See: https://schema.org/PriceSpecification
    Model depth: 4
    """

    type_: str = Field(default="PriceSpecification", alias="@type", const=True)
    priceCurrency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    maxPrice: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The highest price if the price is a range.",
    )
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    membershipPointsEarned: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)",
    )
    eligibleTransactionVolume: Optional[
        Union[List[Union["PriceSpecification", str]], "PriceSpecification", str]
    ] = Field(
        default=None,
        description="The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.",
    )
    minPrice: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The lowest price if the price is a range.",
    )
    valueAddedTaxIncluded: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Specifies whether the applicable value-added tax (VAT) is included in the price specification or not.",
    )
    eligibleQuantity: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.",
    )
    validForMemberTier: Optional[
        Union[List[Union["MemberProgramTier", str]], "MemberProgramTier", str]
    ] = Field(
        default=None,
        description="The membership program tier an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.",
    )
    price: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes. Usage guidelines: * Use the [[priceCurrency]] property (with standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\") instead of including [ambiguous symbols](http://en.wikipedia.org/wiki/Dollar_sign#Currencies_that_use_the_dollar_or_peso_sign) such as '$' in the value. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator. * Note that both [RDFa](http://www.w3.org/TR/xhtml-rdfa-primer/#using-the-content-attribute) and Microdata syntax allow the use of a \"content=\" attribute for publishing simple machine-readable values alongside more human-friendly formatting. * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.",
    )
    validThrough: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.MemberProgramTier import MemberProgramTier



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Article(CreativeWork):
    """An article, such as a news article or piece of investigative report. Newspapers and magazines have articles
     of many different types and this is intended to cover them all. See also [blog post](http://blog.schema.org/2014/09/schemaorg-support-for-bibliographic_2.html).

    See: https://schema.org/Article
    Model depth: 3
    """

    type_: str = Field(default="Article", alias="@type", const=True)
    articleSection: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Articles may belong to one or more 'sections' in a magazine or newspaper, such as Sports, Lifestyle, etc.",
    )
    wordCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of words in the text of the Article.",
    )
    speakable: Optional[
        Union[
            List[Union[AnyUrl, "URL", "SpeakableSpecification", str]],
            AnyUrl,
            "URL",
            "SpeakableSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates sections of a Web page that are particularly 'speakable' in the sense of being highlighted as being especially appropriate for text-to-speech conversion. Other sections of a page may also be usefully spoken in particular circumstances; the 'speakable' property serves to indicate the parts most likely to be generally useful for speech. The *speakable* property can be repeated an arbitrary number of times, with three kinds of possible 'content-locator' values: 1.) *id-value* URL references - uses *id-value* of an element in the page being annotated. The simplest use of *speakable* has (potentially relative) URL values, referencing identified sections of the document concerned. 2.) CSS Selectors - addresses content in the annotated page, e.g. via class attribute. Use the [[cssSelector]] property. 3.) XPaths - addresses content via XPaths (assuming an XML view of the content). Use the [[xpath]] property. For more sophisticated markup of speakable sections beyond simple ID references, either CSS selectors or XPath expressions to pick out document section(s) as speakable. For this we define a supporting type, [[SpeakableSpecification]] which is defined to be a possible value of the *speakable* property.",
    )
    pageStart: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description='The page on which the work starts; for example "135" or "xiii".',
    )
    pagination: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='Any description of pages that is not separated into pageStart and pageEnd; for example, "1-6, 9, 55" or "10-12, 46-49".',
    )
    pageEnd: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description='The page on which the work ends; for example "138" or "xvi".',
    )
    articleBody: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The actual body of the article.",
    )
    backstory: Optional[
        Union[List[Union[str, "Text", "CreativeWork"]], str, "Text", "CreativeWork"]
    ] = Field(
        default=None,
        description="For an [[Article]], typically a [[NewsArticle]], the backstory property provides a textual summary giving a brief explanation of why and how an article was created. In a journalistic setting this could include information about reporting process, methods, interviews, data sources, etc.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.SpeakableSpecification import SpeakableSpecification
    from pydantic2_schemaorg.CreativeWork import CreativeWork



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import datetime
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Reservation import Reservation


class TaxiReservation(Reservation):
    """A reservation for a taxi. Note: This type is for information about actual reservations, e.g. in confirmation
     emails or HTML pages with individual confirmations of reservations. For offers of tickets, use [[Offer]].

    See: https://schema.org/TaxiReservation
    Model depth: 4
    """

    type_: str = Field(default="TaxiReservation", alias="@type", const=True)
    pickupTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="When a taxi will pick up a passenger or a rental car can be picked up.",
    )
    partySize: Optional[
        Union[
            List[Union[int, "Integer", "QuantitativeValue", str]],
            int,
            "Integer",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Number of people the reservation should accommodate.",
    )
    pickupLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="Where a taxi will pick up a passenger or a rental car can be picked up.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Place import Place



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType


class PaidLeave(GovernmentBenefitsType):
    """PaidLeave: this is a benefit for paid leave.

    See: https://schema.org/PaidLeave
    Model depth: 5
    """

    type_: str = Field(default="PaidLeave", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreateAction import CreateAction


class CookAction(CreateAction):
    """The act of producing/preparing food.

    See: https://schema.org/CookAction
    Model depth: 4
    """

    type_: str = Field(default="CookAction", alias="@type", const=True)
    foodEstablishment: Optional[
        Union[
            List[Union["Place", "FoodEstablishment", str]],
            "Place",
            "FoodEstablishment",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of location. The specific food establishment where the action occurred.",
    )
    foodEvent: Optional[Union[List[Union["FoodEvent", str]], "FoodEvent", str]] = Field(
        default=None,
        description="A sub property of location. The specific food event where the action occurred.",
    )
    recipe: Optional[Union[List[Union["Recipe", str]], "Recipe", str]] = Field(
        default=None,
        description="A sub property of instrument. The recipe/instructions used to perform the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.FoodEstablishment import FoodEstablishment
    from pydantic2_schemaorg.FoodEvent import FoodEvent
    from pydantic2_schemaorg.Recipe import Recipe



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Nursing(MedicalSpecialty, MedicalBusiness):
    """A health profession of a person formally educated and trained in the care of the sick or infirm person.

    See: https://schema.org/Nursing
    Model depth: 5
    """

    type_: str = Field(default="Nursing", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration


class DrugPrescriptionStatus(MedicalEnumeration):
    """Indicates whether this drug is available by prescription or over-the-counter.

    See: https://schema.org/DrugPrescriptionStatus
    Model depth: 5
    """

    type_: str = Field(default="DrugPrescriptionStatus", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EnergyEfficiencyEnumeration import EnergyEfficiencyEnumeration


class EUEnergyEfficiencyEnumeration(EnergyEfficiencyEnumeration):
    """Enumerates the EU energy efficiency classes A-G as well as A+, A++, and A+++ as defined in EU directive 2017/1369.

    See: https://schema.org/EUEnergyEfficiencyEnumeration
    Model depth: 5
    """

    type_: str = Field(
        default="EUEnergyEfficiencyEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class LegalService(LocalBusiness):
    """A LegalService is a business that provides legally-oriented services, advice and representation, e.g.
     law firms. As a [[LocalBusiness]] it can be described as a [[provider]] of one or more [[Service]](s).

    See: https://schema.org/LegalService
    Model depth: 4
    """

    type_: str = Field(default="LegalService", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NewsArticle import NewsArticle


class AskPublicNewsArticle(NewsArticle):
    """A [[NewsArticle]] expressing an open call by a [[NewsMediaOrganization]] asking the public for input, insights,
     clarifications, anecdotes, documentation, etc., on an issue, for reporting purposes.

    See: https://schema.org/AskPublicNewsArticle
    Model depth: 5
    """

    type_: str = Field(default="AskPublicNewsArticle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GovernmentOffice import GovernmentOffice


class PostOffice(GovernmentOffice):
    """A post office.

    See: https://schema.org/PostOffice
    Model depth: 5
    """

    type_: str = Field(default="PostOffice", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Event import Event


class SportsEvent(Event):
    """Event type: Sports event.

    See: https://schema.org/SportsEvent
    Model depth: 3
    """

    type_: str = Field(default="SportsEvent", alias="@type", const=True)
    homeTeam: Optional[
        Union[List[Union["SportsTeam", "Person", str]], "SportsTeam", "Person", str]
    ] = Field(
        default=None,
        description="The home team in a sports event.",
    )
    sport: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="A type of sport (e.g. Baseball).",
    )
    competitor: Optional[
        Union[List[Union["SportsTeam", "Person", str]], "SportsTeam", "Person", str]
    ] = Field(
        default=None,
        description="A competitor in a sports event.",
    )
    awayTeam: Optional[
        Union[List[Union["SportsTeam", "Person", str]], "SportsTeam", "Person", str]
    ] = Field(
        default=None,
        description="The away team in a sports event.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.SportsTeam import SportsTeam
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Landform import Landform


class Volcano(Landform):
    """A volcano, like Fujisan.

    See: https://schema.org/Volcano
    Model depth: 4
    """

    type_: str = Field(default="Volcano", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class QuantitativeValue(StructuredValue):
    """A point value or interval for product characteristics and other purposes.

    See: https://schema.org/QuantitativeValue
    Model depth: 4
    """

    type_: str = Field(default="QuantitativeValue", alias="@type", const=True)
    valueReference: Optional[
        Union[
            List[
                Union[
                    str,
                    "Text",
                    "QualitativeValue",
                    "PropertyValue",
                    "Enumeration",
                    "QuantitativeValue",
                    "DefinedTerm",
                    "StructuredValue",
                    "MeasurementTypeEnumeration",
                ]
            ],
            str,
            "Text",
            "QualitativeValue",
            "PropertyValue",
            "Enumeration",
            "QuantitativeValue",
            "DefinedTerm",
            "StructuredValue",
            "MeasurementTypeEnumeration",
        ]
    ] = Field(
        default=None,
        description="A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.",
    )
    unitCode: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.",
    )
    maxValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The upper value of some characteristic or property.",
    )
    value: Optional[
        Union[
            List[
                Union[
                    StrictInt,
                    StrictFloat,
                    "Number",
                    StrictBool,
                    "Boolean",
                    str,
                    "Text",
                    "StructuredValue",
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            StrictBool,
            "Boolean",
            str,
            "Text",
            "StructuredValue",
        ]
    ] = Field(
        default=None,
        description="The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node. * For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'. * For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'. * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.",
    )
    minValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The lower value of some characteristic or property.",
    )
    unitText: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for <a href='unitCode'>unitCode</a>.",
    )
    additionalProperty: Optional[
        Union[List[Union["PropertyValue", str]], "PropertyValue", str]
    ] = Field(
        default=None,
        description="A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org. Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.Enumeration import Enumeration
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.StructuredValue import StructuredValue
    from pydantic2_schemaorg.MeasurementTypeEnumeration import (
        MeasurementTypeEnumeration,
    )
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Boolean import Boolean



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique


class MRI(MedicalImagingTechnique):
    """Magnetic resonance imaging.

    See: https://schema.org/MRI
    Model depth: 6
    """

    type_: str = Field(default="MRI", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class ContactPointOption(Enumeration):
    """Enumerated options related to a ContactPoint.

    See: https://schema.org/ContactPointOption
    Model depth: 4
    """

    type_: str = Field(default="ContactPointOption", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class DrugClass(MedicalEntity):
    """A class of medical drugs, e.g., statins. Classes can represent general pharmacological class, common mechanisms
     of action, common physiological effects, etc.

    See: https://schema.org/DrugClass
    Model depth: 3
    """

    type_: str = Field(default="DrugClass", alias="@type", const=True)
    drug: Optional[Union[List[Union["Drug", str]], "Drug", str]] = Field(
        default=None,
        description="Specifying a drug or medicine used in a medication procedure.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Drug import Drug



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration


class ReducedRelevanceForChildrenConsideration(AdultOrientedEnumeration):
    """A general code for cases where relevance to children is reduced, e.g. adult education, mortgages, retirement-related
     products, etc.

    See: https://schema.org/ReducedRelevanceForChildrenConsideration
    Model depth: 5
    """

    type_: str = Field(
        default="ReducedRelevanceForChildrenConsideration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NewsArticle import NewsArticle


class ReportageNewsArticle(NewsArticle):
    """The [[ReportageNewsArticle]] type is a subtype of [[NewsArticle]] representing news articles which are
     the result of journalistic news reporting conventions. In practice many news publishers produce a wide variety
     of article types, many of which might be considered a [[NewsArticle]] but not a [[ReportageNewsArticle]].
     For example, opinion pieces, reviews, analysis, sponsored or satirical articles, or articles that combine
     several of these elements. The [[ReportageNewsArticle]] type is based on a stricter ideal for \"news\" as
     a work of journalism, with articles based on factual information either observed or verified by the author,
     or reported and verified from knowledgeable sources. This often includes perspectives from multiple viewpoints
     on a particular issue (distinguishing news reports from public relations or propaganda). News reports in
     the [[ReportageNewsArticle]] sense de-emphasize the opinion of the author, with commentary and value judgements
     typically expressed elsewhere. A [[ReportageNewsArticle]] which goes deeper into analysis can also be
     marked with an additional type of [[AnalysisNewsArticle]].

    See: https://schema.org/ReportageNewsArticle
    Model depth: 5
    """

    type_: str = Field(default="ReportageNewsArticle", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class QuantitativeValueDistribution(StructuredValue):
    """A statistical distribution of values.

    See: https://schema.org/QuantitativeValueDistribution
    Model depth: 4
    """

    type_: str = Field(
        default="QuantitativeValueDistribution", alias="@type", const=True
    )
    percentile75: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The 75th percentile value.",
    )
    duration: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    percentile10: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The 10th percentile value.",
    )
    median: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The median value.",
    )
    percentile90: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The 90th percentile value.",
    )
    percentile25: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The 25th percentile value.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Duration import Duration



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaEnumeration import MediaEnumeration


class IPTCDigitalSourceEnumeration(MediaEnumeration):
    """<a href=\"https://www.iptc.org/\">IPTC</a> \"Digital Source\" codes for use with the [[digitalSourceType]]
     property, providing information about the source for a digital media object. In general these codes are not
     declared here to be mutually exclusive, although some combinations would be contradictory if applied simultaneously,
     or might be considered mutually incompatible by upstream maintainers of the definitions. See the IPTC <a
     href=\"https://www.iptc.org/std/photometadata/documentation/userguide/\">documentation</a>
     for <a href=\"https://cv.iptc.org/newscodes/digitalsourcetype/\">detailed definitions</a> of all
     terms.

    See: https://schema.org/IPTCDigitalSourceEnumeration
    Model depth: 5
    """

    type_: str = Field(
        default="IPTCDigitalSourceEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Photograph(CreativeWork):
    """A photograph.

    See: https://schema.org/Photograph
    Model depth: 3
    """

    type_: str = Field(default="Photograph", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Reservation import Reservation


class EventReservation(Reservation):
    """A reservation for an event like a concert, sporting event, or lecture. Note: This type is for information about
     actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations.
     For offers of tickets, use [[Offer]].

    See: https://schema.org/EventReservation
    Model depth: 4
    """

    type_: str = Field(default="EventReservation", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.AddAction import AddAction


class InsertAction(AddAction):
    """The act of adding at a specific location in an ordered collection.

    See: https://schema.org/InsertAction
    Model depth: 5
    """

    type_: str = Field(default="InsertAction", alias="@type", const=True)
    toLocation: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="A sub property of location. The final location of the object or the agent after the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Place import Place



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration
from pydantic2_schemaorg.MedicalProcedure import MedicalProcedure


class PhysicalExam(MedicalEnumeration, MedicalProcedure):
    """A type of physical examination of a patient performed by a physician.

    See: https://schema.org/PhysicalExam
    Model depth: 4
    """

    type_: str = Field(default="PhysicalExam", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BroadcastChannel import BroadcastChannel


class TelevisionChannel(BroadcastChannel):
    """A unique instance of a television BroadcastService on a CableOrSatelliteService lineup.

    See: https://schema.org/TelevisionChannel
    Model depth: 4
    """

    type_: str = Field(default="TelevisionChannel", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Place import Place


class Accommodation(Place):
    """An accommodation is a place that can accommodate human beings, e.g. a hotel room, a camping pitch, or a meeting
     room. Many accommodations are for overnight stays, but this is not a mandatory requirement. For more specific
     types of accommodations not defined in schema.org, one can use [[additionalType]] with external vocabularies.
     <br /><br /> See also the <a href=\"/docs/hotels.html\">dedicated document on the use of schema.org for
     marking up hotels and other forms of accommodations</a>.

    See: https://schema.org/Accommodation
    Model depth: 3
    """

    type_: str = Field(default="Accommodation", alias="@type", const=True)
    permittedUsage: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Indications regarding the permitted usage of the accommodation.",
    )
    numberOfBedrooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].",
    )
    accommodationCategory: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="Category of an [[Accommodation]], following real estate conventions, e.g. RESO (see [PropertySubType](https://ddwiki.reso.org/display/DDW17/PropertySubType+Field), and [PropertyType](https://ddwiki.reso.org/display/DDW17/PropertyType+Field) fields for suggested values).",
        )
    )
    floorSize: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The size of the accommodation, e.g. in square meter or squarefoot. Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard.",
    )
    occupancy: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The allowed total occupancy for the accommodation in persons (including infants etc). For individual accommodations, this is not necessarily the legal maximum but defines the permitted usage as per the contractual agreement (e.g. a double room used by a single person). Typical unit code(s): C62 for person.",
    )
    petsAllowed: Optional[
        Union[
            List[Union[StrictBool, "Boolean", str, "Text"]],
            StrictBool,
            "Boolean",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.",
    )
    numberOfFullBathrooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsFull field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsFull+Field).",
    )
    numberOfPartialBathrooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsPartial field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsPartial+Field).",
    )
    floorLevel: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The floor level for an [[Accommodation]] in a multi-storey building. Since counting systems [vary internationally](https://en.wikipedia.org/wiki/Storey#Consecutive_number_floor_designations), the local system should be used where possible.",
    )
    amenityFeature: Optional[
        Union[
            List[Union["LocationFeatureSpecification", str]],
            "LocationFeatureSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.",
    )
    leaseLength: Optional[
        Union[
            List[Union["Duration", "QuantitativeValue", str]],
            "Duration",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Length of the lease for some [[Accommodation]], either particular to some [[Offer]] or in some cases intrinsic to the property.",
    )
    numberOfRooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.",
    )
    bed: Optional[
        Union[
            List[Union[str, "Text", "BedType", "BedDetails"]],
            str,
            "Text",
            "BedType",
            "BedDetails",
        ]
    ] = Field(
        default=None,
        description="The type of bed or beds included in the accommodation. For the single case of just one bed of a certain type, you use bed directly with a text. If you want to indicate the quantity of a certain kind of bed, use an instance of BedDetails. For more detailed information, use the amenityFeature property.",
    )
    yearBuilt: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The year an [[Accommodation]] was constructed. This corresponds to the [YearBuilt field in RESO](https://ddwiki.reso.org/display/DDW17/YearBuilt+Field).",
    )
    tourBookingPage: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate.",
    )
    accommodationFloorPlan: Optional[
        Union[List[Union["FloorPlan", str]], "FloorPlan", str]
    ] = Field(
        default=None,
        description="A floorplan of some [[Accommodation]].",
    )
    numberOfBathroomsTotal: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description='The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as [documented in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsTotalInteger+Field): "The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.". See also [[numberOfRooms]].',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.LocationFeatureSpecification import (
        LocationFeatureSpecification,
    )
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.BedType import BedType
    from pydantic2_schemaorg.BedDetails import BedDetails
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.FloorPlan import FloorPlan
    from pydantic2_schemaorg.Integer import Integer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyOfWater import BodyOfWater


class LakeBodyOfWater(BodyOfWater):
    """A lake (for example, Lake Pontrachain).

    See: https://schema.org/LakeBodyOfWater
    Model depth: 5
    """

    type_: str = Field(default="LakeBodyOfWater", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EmergencyService import EmergencyService
from pydantic2_schemaorg.CivicStructure import CivicStructure


class PoliceStation(EmergencyService, CivicStructure):
    """A police station.

    See: https://schema.org/PoliceStation
    Model depth: 4
    """

    type_: str = Field(default="PoliceStation", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501n(USNonprofitType):
    """Nonprofit501n: Non-profit type referring to Charitable Risk Pools.

    See: https://schema.org/Nonprofit501n
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501n", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Project import Project


class ResearchProject(Project):
    """A Research project.

    See: https://schema.org/ResearchProject
    Model depth: 4
    """

    type_: str = Field(default="ResearchProject", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalOrganization import MedicalOrganization


class VeterinaryCare(MedicalOrganization):
    """A vet's office.

    See: https://schema.org/VeterinaryCare
    Model depth: 4
    """

    type_: str = Field(default="VeterinaryCare", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementHand(BodyMeasurementTypeEnumeration):
    """Maximum hand girth (measured over the knuckles of the open right hand excluding thumb, fingers together).
     Used, for example, to fit gloves.

    See: https://schema.org/BodyMeasurementHand
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementHand", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class WebSite(CreativeWork):
    """A WebSite is a set of related web pages and other items typically served from a single web domain and accessible
     via URLs.

    See: https://schema.org/WebSite
    Model depth: 3
    """

    type_: str = Field(default="WebSite", alias="@type", const=True)
    issn: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NewsArticle import NewsArticle


class AnalysisNewsArticle(NewsArticle):
    """An AnalysisNewsArticle is a [[NewsArticle]] that, while based on factual reporting, incorporates the expertise
     of the author/producer, offering interpretations and conclusions.

    See: https://schema.org/AnalysisNewsArticle
    Model depth: 5
    """

    type_: str = Field(default="AnalysisNewsArticle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWorkSeries import CreativeWorkSeries


class Periodical(CreativeWorkSeries):
    """A publication in any medium issued in successive parts bearing numerical or chronological designations
     and intended to continue indefinitely, such as a magazine, scholarly journal, or newspaper. See also [blog
     post](http://blog.schema.org/2014/09/schemaorg-support-for-bibliographic_2.html).

    See: https://schema.org/Periodical
    Model depth: 4
    """

    type_: str = Field(default="Periodical", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ListItem(Intangible):
    """An list item, e.g. a step in a checklist or how-to description.

    See: https://schema.org/ListItem
    Model depth: 3
    """

    type_: str = Field(default="ListItem", alias="@type", const=True)
    item: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="An entity represented by an entry in a list or data feed (e.g. an 'artist' in a list of 'artists').",
    )
    previousItem: Optional[Union[List[Union["ListItem", str]], "ListItem", str]] = (
        Field(
            default=None,
            description="A link to the ListItem that precedes the current one.",
        )
    )
    position: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description="The position of an item in a series or sequence of items.",
    )
    nextItem: Optional[Union[List[Union["ListItem", str]], "ListItem", str]] = Field(
        default=None,
        description="A link to the ListItem that follows the current one.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTrialDesign import MedicalTrialDesign


class OpenTrial(MedicalTrialDesign):
    """A trial design in which the researcher knows the full details of the treatment, and so does the patient.

    See: https://schema.org/OpenTrial
    Model depth: 6
    """

    type_: str = Field(default="OpenTrial", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Review import Review


class ClaimReview(Review):
    """A fact-checking review of claims made (or reported) in some creative work (referenced via itemReviewed).

    See: https://schema.org/ClaimReview
    Model depth: 4
    """

    type_: str = Field(default="ClaimReview", alias="@type", const=True)
    claimReviewed: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A short summary of the specific claims reviewed in a ClaimReview.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration


class DrugCostCategory(MedicalEnumeration):
    """Enumerated categories of medical drug costs.

    See: https://schema.org/DrugCostCategory
    Model depth: 5
    """

    type_: str = Field(default="DrugCostCategory", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class SubscribeAction(InteractAction):
    """The act of forming a personal connection with someone/something (object) unidirectionally/asymmetrically
     to get updates pushed to. Related actions: * [[FollowAction]]: Unlike FollowAction, SubscribeAction implies
     that the subscriber acts as a passive agent being constantly/actively pushed for updates. * [[RegisterAction]]:
     Unlike RegisterAction, SubscribeAction implies that the agent is interested in continuing receiving updates
     from the object. * [[JoinAction]]: Unlike JoinAction, SubscribeAction implies that the agent is interested
     in continuing receiving updates from the object.

    See: https://schema.org/SubscribeAction
    Model depth: 4
    """

    type_: str = Field(default="SubscribeAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class DefinedTermSet(CreativeWork):
    """A set of defined terms, for example a set of categories or a classification scheme, a glossary, dictionary
     or enumeration.

    See: https://schema.org/DefinedTermSet
    Model depth: 3
    """

    type_: str = Field(default="DefinedTermSet", alias="@type", const=True)
    hasDefinedTerm: Optional[
        Union[List[Union["DefinedTerm", str]], "DefinedTerm", str]
    ] = Field(
        default=None,
        description="A Defined Term contained in this term set.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WearableMeasurementTypeEnumeration import (
    WearableMeasurementTypeEnumeration,
)


class WearableMeasurementOutsideLeg(WearableMeasurementTypeEnumeration):
    """Measurement of the outside leg, for example of pants.

    See: https://schema.org/WearableMeasurementOutsideLeg
    Model depth: 6
    """

    type_: str = Field(
        default="WearableMeasurementOutsideLeg", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.StatusEnumeration import StatusEnumeration


class PaymentStatusType(StatusEnumeration):
    """A specific payment status. For example, PaymentDue, PaymentComplete, etc.

    See: https://schema.org/PaymentStatusType
    Model depth: 5
    """

    type_: str = Field(default="PaymentStatusType", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.UseAction import UseAction


class WearAction(UseAction):
    """The act of dressing oneself in clothing.

    See: https://schema.org/WearAction
    Model depth: 5
    """

    type_: str = Field(default="WearAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalCondition import MedicalCondition


class InfectiousDisease(MedicalCondition):
    """An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial
     agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and
     prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease.

    See: https://schema.org/InfectiousDisease
    Model depth: 4
    """

    type_: str = Field(default="InfectiousDisease", alias="@type", const=True)
    transmissionMethod: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="How the disease spreads, either as a route or vector, for example 'direct contact', 'Aedes aegypti', etc.",
    )
    infectiousAgent: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The actual infectious agent, such as a specific bacterium.",
    )
    infectiousAgentClass: Optional[
        Union[List[Union["InfectiousAgentClass", str]], "InfectiousAgentClass", str]
    ] = Field(
        default=None,
        description="The class of infectious agent (bacteria, prion, etc.) that causes the disease.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.InfectiousAgentClass import InfectiousAgentClass



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.OrderStatus import OrderStatus


class OrderPaymentDue(OrderStatus):
    """OrderStatus representing that payment is due on an order.

    See: https://schema.org/OrderPaymentDue
    Model depth: 6
    """

    type_: str = Field(default="OrderPaymentDue", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Obstetric(MedicalSpecialty, MedicalBusiness):
    """A specific branch of medical science that specializes in the care of women during the prenatal and postnatal
     care and with the delivery of the child.

    See: https://schema.org/Obstetric
    Model depth: 5
    """

    type_: str = Field(default="Obstetric", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union
from datetime import date


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Legislation(CreativeWork):
    """A legal document such as an act, decree, bill, etc. (enforceable or not) or a component of a legal act (like an
     article).

    See: https://schema.org/Legislation
    Model depth: 3
    """

    type_: str = Field(default="Legislation", alias="@type", const=True)
    legislationIdentifier: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="An identifier for the legislation. This can be either a string-based identifier, like the CELEX at EU level or the NOR in France, or a web-based, URL/URI identifier, like an ELI (European Legislation Identifier) or an URN-Lex.",
    )
    jurisdiction: Optional[
        Union[
            List[Union[str, "Text", "AdministrativeArea"]],
            str,
            "Text",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based.",
    )
    legislationDate: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description="The date of adoption or signature of the legislation. This is the date at which the text is officially aknowledged to be a legislation, even though it might not even be published or in force.",
    )
    legislationPassedBy: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description='The person or organization that originally passed or made the law: typically parliament (for primary legislation) or government (for secondary legislation). This indicates the "legal author" of the law, as opposed to its physical author.',
    )
    legislationJurisdiction: Optional[
        Union[
            List[Union[str, "Text", "AdministrativeArea"]],
            str,
            "Text",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="The jurisdiction from which the legislation originates.",
    )
    legislationLegalForce: Optional[
        Union[List[Union["LegalForceStatus", str]], "LegalForceStatus", str]
    ] = Field(
        default=None,
        description="Whether the legislation is currently in force, not in force, or partially in force.",
    )
    legislationResponsible: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An individual or organization that has some kind of responsibility for the legislation. Typically the ministry who is/was in charge of elaborating the legislation, or the adressee for potential questions about the legislation once it is published.",
    )
    legislationApplies: Optional[
        Union[List[Union["Legislation", str]], "Legislation", str]
    ] = Field(
        default=None,
        description='Indicates that this legislation (or part of a legislation) somehow transfers another legislation in a different legislative context. This is an informative link, and it has no legal value. For legally-binding links of transposition, use the <a href="/legislationTransposes">legislationTransposes</a> property. For example an informative consolidated law of a European Union\'s member state "applies" the consolidated version of the European Directive implemented in it.',
    )
    legislationType: Optional[
        Union[List[Union[str, "Text", "CategoryCode"]], str, "Text", "CategoryCode"]
    ] = Field(
        default=None,
        description='The type of the legislation. Examples of values are "law", "act", "directive", "decree", "regulation", "statutory instrument", "loi organique", "règlement grand-ducal", etc., depending on the country.',
    )
    legislationConsolidates: Optional[
        Union[List[Union["Legislation", str]], "Legislation", str]
    ] = Field(
        default=None,
        description="Indicates another legislation taken into account in this consolidated legislation (which is usually the product of an editorial process that revises the legislation). This property should be used multiple times to refer to both the original version or the previous consolidated version, and to the legislations making the change.",
    )
    legislationChanges: Optional[
        Union[List[Union["Legislation", str]], "Legislation", str]
    ] = Field(
        default=None,
        description='Another legislation that this legislation changes. This encompasses the notions of amendment, replacement, correction, repeal, or other types of change. This may be a direct change (textual or non-textual amendment) or a consequential or indirect change. The property is to be used to express the existence of a change relationship between two acts rather than the existence of a consolidated version of the text that shows the result of the change. For consolidation relationships, use the <a href="/legislationConsolidates">legislationConsolidates</a> property.',
    )
    legislationDateVersion: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description='The point-in-time at which the provided description of the legislation is valid (e.g.: when looking at the law on the 2016-04-07 (= dateVersion), I get the consolidation of 2015-04-12 of the "National Insurance Contributions Act 2015")',
    )
    legislationTransposes: Optional[
        Union[List[Union["Legislation", str]], "Legislation", str]
    ] = Field(
        default=None,
        description="Indicates that this legislation (or part of legislation) fulfills the objectives set by another legislation, by passing appropriate implementation measures. Typically, some legislations of European Union's member states or regions transpose European Directives. This indicates a legally binding link between the 2 legislations.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.LegalForceStatus import LegalForceStatus
    from pydantic2_schemaorg.CategoryCode import CategoryCode



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl, StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class OfferShippingDetails(StructuredValue):
    """OfferShippingDetails represents information about shipping destinations. Multiple of these entities
     can be used to represent different shipping rates for different destinations: One entity for Alaska/Hawaii.
     A different one for continental US. A different one for all France. Multiple of these entities can be used to
     represent different shipping costs and delivery times. Two entities that are identical but differ in rate
     and time: E.g. Cheaper and slower: $5 in 5-7 days or Fast and expensive: $15 in 1-2 days.

    See: https://schema.org/OfferShippingDetails
    Model depth: 4
    """

    type_: str = Field(default="OfferShippingDetails", alias="@type", const=True)
    doesNotShip: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Indicates when shipping to a particular [[shippingDestination]] is not available.",
    )
    shippingRate: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate.",
    )
    weight: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The weight of the product or person.",
    )
    width: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The width of the item.",
    )
    shippingLabel: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).",
    )
    shippingDestination: Optional[
        Union[List[Union["DefinedRegion", str]], "DefinedRegion", str]
    ] = Field(
        default=None,
        description="indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.",
    )
    shippingSettingsLink: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="Link to a page containing [[ShippingRateSettings]] and [[DeliveryTimeSettings]] details.",
    )
    validForMemberTier: Optional[
        Union[List[Union["MemberProgramTier", str]], "MemberProgramTier", str]
    ] = Field(
        default=None,
        description="The membership program tier an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.",
    )
    deliveryTime: Optional[
        Union[List[Union["ShippingDeliveryTime", str]], "ShippingDeliveryTime", str]
    ] = Field(
        default=None,
        description="The total delay between the receipt of the order and the goods reaching the final customer.",
    )
    height: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The height of the item.",
    )
    shippingOrigin: Optional[
        Union[List[Union["DefinedRegion", str]], "DefinedRegion", str]
    ] = Field(
        default=None,
        description="Indicates the origin of a shipment, i.e. where it should be coming from.",
    )
    transitTimeLabel: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Label to match an [[OfferShippingDetails]] with a [[DeliveryTimeSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).",
    )
    depth: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The depth of the item.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Distance import Distance
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedRegion import DefinedRegion
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.MemberProgramTier import MemberProgramTier
    from pydantic2_schemaorg.ShippingDeliveryTime import ShippingDeliveryTime



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicineSystem import MedicineSystem


class Homeopathic(MedicineSystem):
    """A system of medicine based on the principle that a disease can be cured by a substance that produces similar
     symptoms in healthy people.

    See: https://schema.org/Homeopathic
    Model depth: 6
    """

    type_: str = Field(default="Homeopathic", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Quantity(Intangible):
    """Quantities such as distance, time, mass, weight, etc. Particular instances of say Mass are entities like
     '3 kg' or '4 milligrams'.

    See: https://schema.org/Quantity
    Model depth: 3
    """

    type_: str = Field(default="Quantity", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalIndication import MedicalIndication


class ApprovedIndication(MedicalIndication):
    """An indication for a medical therapy that has been formally specified or approved by a regulatory body that
     regulates use of the therapy; for example, the US FDA approves indications for most drugs in the US.

    See: https://schema.org/ApprovedIndication
    Model depth: 4
    """

    type_: str = Field(default="ApprovedIndication", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class DefinedTerm(Intangible):
    """A word, name, acronym, phrase, etc. with a formal definition. Often used in the context of category or subject
     classification, glossaries or dictionaries, product or creative work types, etc. Use the name property
     for the term being defined, use termCode if the term has an alpha-numeric code allocated, use description
     to provide the definition of the term.

    See: https://schema.org/DefinedTerm
    Model depth: 3
    """

    type_: str = Field(default="DefinedTerm", alias="@type", const=True)
    inDefinedTermSet: Optional[
        Union[
            List[Union[AnyUrl, "URL", "DefinedTermSet", str]],
            AnyUrl,
            "URL",
            "DefinedTermSet",
            str,
        ]
    ] = Field(
        default=None,
        description="A [[DefinedTermSet]] that contains this term.",
    )
    termCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A code that identifies this [[DefinedTerm]] within a [[DefinedTermSet]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.DefinedTermSet import DefinedTermSet
    from pydantic2_schemaorg.Text import Text
